@@ -780,11 +780,27 @@ class Browser(webdriver.Chrome):
             chrome_options.binary_location = binary_location
             _logger.info('using chrome binary >>>%s<<<', chrome_options.binary_location)
 
-        # re '--no-sandbox' - see https://github.com/theintern/intern/issues/878
+        #
+        # -- https://peter.sh/experiments/chromium-command-line-switches/
+        # --no-sandbox
+        #   -- https://github.com/theintern/intern/issues/878
+        # --single-process added after reading
+        #   -- https://github.com/adieuadieu/serverless-chrome/issues/15
+        # --disable-gpu
+        #   -- added after reading although seems that --headless might make that redundent
+        #   -- https://stackoverflow.com/questions/64029465/how-to-debug-headless-pdf-printing-problems-in-chrome
+        # --disable-software-rasterizer added after reading
+        #   -- https://stackoverflow.com/questions/61773844/...
+        #   the-gpu-process-has-crashed-x-times-error-using-chromedriver-and-chrome-in-hea
+        #   -- https://chromium-review.googlesource.com/c/chromium/src/+/522068/
+        #
         chrome_options_str_format = (
             '--headless|'
             '--window-size=1280x1024|'
             '--no-sandbox|'
+            '--disable-gpu|'
+            '--disable-software-rasterizer|'
+            '--single-process|'
             '--disable-dev-shm-usage|'
             '--user-agent={user_agent}'
         )
